<?php

/*
 * USEFUL FUNCTIONS FOR USE IN THEME/TEMPLATE FILES * * * * * * * * * * * * * *
 */

// returns a string with the path to the post's or page's image
// ( used only on search results so far. 70x70 size hard-coded )
function asfp_get_image($postid,$size='thumbnail',$class='') {
	$image_url = '';
	
	if (function_exists('has_post_thumbnail')) {
		if (has_post_thumbnail($postid)) {
			$image_id = get_post_thumbnail_id();
			$image_url = wp_get_attachment_image_src($image_id,$size);
			$image_url = $image_url[0];
		}
	}

	if (empty($image_url)) {
	    $arrImages =& get_children('post_type=attachment&post_mime_type=image&post_parent='.$postid );
	    if ($arrImages) {
	        // Get array keys representing attached image numbers
	        $arrKeys = array_keys($arrImages);
	        // Get the first image attachment
	        $iNum = $arrKeys[0];
	        // return the url for the attachment
	        $imginfo = wp_get_attachment_image_src($iNum,$size);
	        $image_url = $imginfo[0];
		} 
	}
	
	if (!empty($image_url)) {
		$str = '<img src="'.$image_url.'" class="'.$class.'" width="70" height="70" />';
		return $str;
	}
}

// prints out a list of the current page's children or siblings in a widget div
function asfp_subpages_nav($args=null) {
	parse_str($args,$arg); // link_heading
	global $post;
	
	if (is_page() && !is_404() && !is_search() && !is_front_page()) {
		// If CHILD_OF is not NULL, then this page has a parent
		// Therefore, list siblings i.e. subpages of this page's parent
		if ($post->post_parent)
		    $thelist = wp_list_pages('echo=0&title_li=&depth=2&sort_column=menu_order&child_of='.asfp_get_ancestor());
		// If CHILD_OF is zero, this is a top level page, so list subpages only.
		else
		    $thelist = wp_list_pages('echo=0&title_li=&depth=2&sort_column=menu_order&child_of='.$post->ID);
		if (!empty($thelist)):
			if ($post->post_parent) {
				$sectitle = get_the_title(asfp_get_ancestor());
				$securl = get_permalink(asfp_get_ancestor());
			} else {
				$sectitle = get_the_title($post->ID); 
				$securl = get_permalink($post->ID);
			} ?>
			<div class="widget asfp_subpages_nav">
				<h3><?php if (isset($arg['link_heading'])) echo '<a href="'.$securl.'">'; echo $sectitle; if (isset($arg['link_heading'])) echo '</a>' ?></h3>
				<div class="asfp_nav_box">
				<ul>
					<?php echo $thelist ?>
				</ul>
				</div>
			</div>
		<?php endif;
	}
}


/*
 * USED BY THE FUNCTIONS ABOVE * * * * * * * * * * * * * * * * * * * * * * * * * *
 */
 
// returns the page id of the parent or grandparent of the current page
function asfp_get_ancestor() {
	global $post;
	if ($post->post_parent) {
		$ancestor = get_posts('post_type=page&include='.$post->post_parent);
		if ($ancestor[0]->post_parent) return $ancestor[0]->post_parent;
		else return $post->post_parent;
	} else return false;
}


/*
 *	NOT A TEMPLATE FUNCTION * * * * * * * * * * * * * * * * * * * * * * * * * * *
 */

// Used by document types feature
function asfp_doctypes_regex($text) {
	$types = get_option('asfp_doctypes_list');
	$types = ereg_replace(',[:space:]*','|',$types);
	// add the class to links
	$text = eregi_replace('href=([\'|"][[:alnum:]|[:punct:]]*)\.('.$types.')([\'|"])','href=\\1.\\2\\3 class="link \\2"',$text);
	// remove the class from links followed directly by an image tag
	$text = ereg_replace('(<a[^>]+)class="link [^"]+"([^>]*>)<img','\\1\\2<img',$text);
	return $text;
}
?>